pub struct Client { /* private fields */ }Expand description
Defines the client itself, all Notification Server actions are done through an instance of this struct.
Implementations
Sourceimpl Client
impl Client
Sourcepub async fn new(server: &str, port: u16) -> Result<Self, SdkError>
pub async fn new(server: &str, port: u16) -> Result<Self, SdkError>
Connects to the server, defines the channels and returns a new instance.
Sourcepub fn add_event_handler_closure<F, R>(&self, f: F)
pub fn add_event_handler_closure<F, R>(&self, f: F)
Adds a handler closure. If you’re using this SDK with Rust, not through a foreign language binding, then this is the preferred method of receiving and handling events.
Sourcepub async fn login(
&self,
email: String,
password: &str,
nexus_url: &str,
client_name: &str,
version: &str,
) -> Result<Event, SdkError>
pub async fn login( &self, email: String, password: &str, nexus_url: &str, client_name: &str, version: &str, ) -> Result<Event, SdkError>
Does the MSNP authentication process. Also starts regular pings and the handler for Switchboard invitations.
Events
If the server you’re connecting to implements a Dispatch Server, then this will return a RedirectedTo event. What follows is creating a new client instance with the server and port returned then logging in again, which will return an Authenticated event.
Sourcepub async fn set_presence(&self, presence: MsnpStatus) -> Result<(), SdkError>
pub async fn set_presence(&self, presence: MsnpStatus) -> Result<(), SdkError>
Sets the user’s presence status.
Sourcepub async fn set_personal_message(
&self,
personal_message: &PersonalMessage,
) -> Result<(), SdkError>
pub async fn set_personal_message( &self, personal_message: &PersonalMessage, ) -> Result<(), SdkError>
Sets the user’s personal message.
Sourcepub async fn set_display_name(&self, display_name: &str) -> Result<(), SdkError>
pub async fn set_display_name(&self, display_name: &str) -> Result<(), SdkError>
Sets the user’s display name.
Sourcepub async fn set_contact_display_name(
&self,
guid: &str,
display_name: &str,
) -> Result<(), ContactError>
pub async fn set_contact_display_name( &self, guid: &str, display_name: &str, ) -> Result<(), ContactError>
Sets a contact’s display name.
Sourcepub async fn add_contact(
&self,
email: &str,
display_name: &str,
list: MsnpList,
) -> Result<Event, ContactError>
pub async fn add_contact( &self, email: &str, display_name: &str, list: MsnpList, ) -> Result<Event, ContactError>
Adds a contact to a specified list, also setting its display name if applicable.
Sourcepub async fn remove_contact(
&self,
email: &str,
list: MsnpList,
) -> Result<(), ContactError>
pub async fn remove_contact( &self, email: &str, list: MsnpList, ) -> Result<(), ContactError>
Removes a contact from a specified list (except the forward list, which requires calling remove_contact_from_forward_list).
Sourcepub async fn remove_contact_from_forward_list(
&self,
guid: &str,
) -> Result<(), ContactError>
pub async fn remove_contact_from_forward_list( &self, guid: &str, ) -> Result<(), ContactError>
Removes a contact from the forward list.
Sourcepub async fn block_contact(&self, email: &str) -> Result<(), ContactError>
pub async fn block_contact(&self, email: &str) -> Result<(), ContactError>
Blocks a contact.
Sourcepub async fn unblock_contact(&self, email: &str) -> Result<(), ContactError>
pub async fn unblock_contact(&self, email: &str) -> Result<(), ContactError>
Unblocks a contact.
Sourcepub async fn create_group(&self, name: &str) -> Result<(), ContactError>
pub async fn create_group(&self, name: &str) -> Result<(), ContactError>
Creates a new contact group.
Sourcepub async fn delete_group(&self, guid: &str) -> Result<(), ContactError>
pub async fn delete_group(&self, guid: &str) -> Result<(), ContactError>
Deletes a contact group.
Sourcepub async fn rename_group(
&self,
guid: &str,
new_name: &str,
) -> Result<(), ContactError>
pub async fn rename_group( &self, guid: &str, new_name: &str, ) -> Result<(), ContactError>
Renames a contact group.
Sourcepub async fn add_contact_to_group(
&self,
guid: &str,
group_guid: &str,
) -> Result<(), ContactError>
pub async fn add_contact_to_group( &self, guid: &str, group_guid: &str, ) -> Result<(), ContactError>
Adds a contact to a group.
Sourcepub async fn remove_contact_from_group(
&self,
guid: &str,
group_guid: &str,
) -> Result<(), ContactError>
pub async fn remove_contact_from_group( &self, guid: &str, group_guid: &str, ) -> Result<(), ContactError>
Removes a contact from a group.
Sourcepub async fn set_gtc(&self, gtc: &str) -> Result<(), SdkError>
pub async fn set_gtc(&self, gtc: &str) -> Result<(), SdkError>
Sets the GTC value, which can be either A or N.
Sourcepub async fn set_blp(&self, blp: &str) -> Result<(), SdkError>
pub async fn set_blp(&self, blp: &str) -> Result<(), SdkError>
Sets the BLP value, which can be either AL or BL.
Sourcepub async fn create_session(&self, email: &str) -> Result<Switchboard, SdkError>
pub async fn create_session(&self, email: &str) -> Result<Switchboard, SdkError>
Creates a new Switchboard session and invites the specified contact to it.
Sourcepub async fn set_display_picture(
&self,
display_picture: Vec<u8>,
) -> Result<String, SdkError>
pub async fn set_display_picture( &self, display_picture: Vec<u8>, ) -> Result<String, SdkError>
Sets the user’s display picture, returning a standard base64 encoded hash of it. This method uses the picture’s binary data, and scaling down to a size like 200x200 beforehand is recommended.
Sourcepub async fn disconnect(&self) -> Result<(), SdkError>
pub async fn disconnect(&self) -> Result<(), SdkError>
Disconnects from the server.